import { PolkadotSigner, SigningManager } from '@polymathnetwork/signing-manager-types';
import { NetworkInfo, UnsubCallback } from '../types';
export declare class BrowserExtensionSigningManager implements SigningManager {
    private readonly extension;
    private _ss58Format?;
    /**
     * Create a Signing Manager that connects to a browser extension
     *
     * @param args.appName - name of the dApp attempting to connect to the extension
     * @param args.extensionName - name of the extension to be used (optional, defaults to 'polywallet')
     *
     * @note if this is the first time the user is interacting with the dApp using that specific extension,
     *   they will be prompted by the extension to add the dApp to the allowed list
     *
     * @throws
     *   - if there is no extension with the passed name
     *   - if there is more than one extension with the passed name (one should be disabled)
     *   - if the extension has blocked permissions for the dApp
     */
    static create(args: {
        appName: string;
        extensionName?: string;
    }): Promise<BrowserExtensionSigningManager>;
    private constructor();
    /**
     * Set the SS58 format in which returned addresses will be encoded
     */
    setSs58Format(ss58Format: number): void;
    /**
     * Return the addresses of all Accounts in the Browser Wallet Extension
     *
     * @throws if called before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    getAccounts(): Promise<string[]>;
    /**
     * Return a signer object that uses the extension Accounts to sign
     */
    getExternalSigner(): PolkadotSigner;
    /**
     * Subscribes via callback to any change in the extension's Accounts. This can be either
     *   from an Account being added/removed, or from the user changing the selected Account
     *
     * The callback will be called with the new array of Accounts
     *
     * Convention is for the current selected Account to be the first value in the array, but it
     *   depends on the extension implementation
     *
     * @throws if the callback is triggered before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    onAccountChange(cb: (accounts: string[]) => void): UnsubCallback;
    /**
     * Subscribes via callback to a change in the extension's selected network (i.e. going from Testnet to Mainnet)
     *
     * The callback will be called with the new network information
     */
    onNetworkChange(cb: (networkInfo: NetworkInfo) => void): UnsubCallback;
    /**
     * @hidden
     *
     * @throws if the SS58 format hasn't been set yet
     */
    private getSs58Format;
}
