"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BrowserExtensionSigningManager = void 0;
const tslib_1 = require("tslib");
const extension_dapp_1 = require("@polkadot/extension-dapp");
const utils_1 = require("../utils");
class BrowserExtensionSigningManager {
    constructor(extension) {
        this.extension = extension;
    }
    /**
     * Create a Signing Manager that connects to a browser extension
     *
     * @param args.appName - name of the dApp attempting to connect to the extension
     * @param args.extensionName - name of the extension to be used (optional, defaults to 'polywallet')
     *
     * @note if this is the first time the user is interacting with the dApp using that specific extension,
     *   they will be prompted by the extension to add the dApp to the allowed list
     *
     * @throws
     *   - if there is no extension with the passed name
     *   - if there is more than one extension with the passed name (one should be disabled)
     *   - if the extension has blocked permissions for the dApp
     */
    static create(args) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const { appName, extensionName = 'polywallet' } = args;
            const extensions = yield (0, extension_dapp_1.web3Enable)(appName);
            const filteredExtensions = extensions.filter(({ name }) => name === extensionName);
            if (filteredExtensions.length === 0) {
                throw new Error(`There is no extension named "${extensionName}", or the extension has blocked the "${appName}" dApp`);
            }
            if (filteredExtensions.length > 1) {
                throw new Error(`There is more than one extension named "${extensionName}"`);
            }
            return new BrowserExtensionSigningManager(filteredExtensions[0]);
        });
    }
    /**
     * Set the SS58 format in which returned addresses will be encoded
     */
    setSs58Format(ss58Format) {
        this._ss58Format = ss58Format;
    }
    /**
     * Return the addresses of all Accounts in the Browser Wallet Extension
     *
     * @throws if called before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    getAccounts() {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            const ss58Format = this.getSs58Format('getAccounts');
            const accounts = yield this.extension.accounts.get();
            // we make sure the addresses are returned in the correct SS58 format
            return accounts.map(({ address }) => (0, utils_1.changeAddressFormat)(address, ss58Format));
        });
    }
    /**
     * Return a signer object that uses the extension Accounts to sign
     */
    getExternalSigner() {
        return this.extension.signer;
    }
    /**
     * Subscribes via callback to any change in the extension's Accounts. This can be either
     *   from an Account being added/removed, or from the user changing the selected Account
     *
     * The callback will be called with the new array of Accounts
     *
     * Convention is for the current selected Account to be the first value in the array, but it
     *   depends on the extension implementation
     *
     * @throws if the callback is triggered before calling `setSs58Format`. Normally, `setSs58Format` will be called by the SDK when instantiated
     */
    onAccountChange(cb) {
        let ss58Format;
        return this.extension.accounts.subscribe(accounts => {
            if (!ss58Format) {
                ss58Format = this.getSs58Format('onAccountChange callback');
            }
            cb(accounts.map(({ address }) => (0, utils_1.changeAddressFormat)(address, ss58Format)));
        });
    }
    /**
     * Subscribes via callback to a change in the extension's selected network (i.e. going from Testnet to Mainnet)
     *
     * The callback will be called with the new network information
     */
    onNetworkChange(cb) {
        return this.extension.network.subscribe(cb);
    }
    /**
     * @hidden
     *
     * @throws if the SS58 format hasn't been set yet
     */
    getSs58Format(methodName) {
        const { _ss58Format: format } = this;
        if (format === undefined) {
            throw new Error(`Cannot call '${methodName}' before calling 'setSs58Format'. Did you forget to use this Signing Manager to connect with the Polymesh SDK?`);
        }
        return format;
    }
}
exports.BrowserExtensionSigningManager = BrowserExtensionSigningManager;
//# sourceMappingURL=browser-extension-signing-manager.js.map